@@ -31,14 +31,14 @@
  * o The bitfield in mongoc-handshake-private.h
  * o _mongoc_handshake_get_config_hex_string() in mongoc-handshake.c
  * o examples/parse_handshake_cfg.py
- * o test_handshake_config_string in test-mongoc-handshake.c
+ * o test_handshake_platform_config in test-mongoc-handshake.c
  */
 
 /* MONGOC_USER_SET_CFLAGS is set from config based on what compiler flags were
  * used to compile mongoc */
-#define MONGOC_USER_SET_CFLAGS "-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -g -ffile-prefix-map=/build/mongo-c-driver/src=/usr/src/debug/mongo-c-driver -flto=auto"
+#define MONGOC_USER_SET_CFLAGS "-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -g -ffile-prefix-map=/build/mongo-c-driver/src=/usr/src/debug/mongo-c-driver -flto=auto"
 
-#define MONGOC_USER_SET_LDFLAGS "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now -flto=auto"
+#define MONGOC_USER_SET_LDFLAGS "-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto"
 
 /* MONGOC_CC is used to determine what C compiler was used to compile mongoc */
 #define MONGOC_CC "/usr/bin/cc"
@@ -226,6 +226,10 @@
 #  undef MONGOC_HAVE_SOCKLEN
 #endif
 
+/**
+ * @brief Defined to 0/1 for whether we were configured with ENABLE_SRV
+ */
+#define MONGOC_ENABLE_SRV 1
 
 /*
  * MONGOC_HAVE_DNSAPI is set from configure to determine if we should use the
@@ -276,7 +280,7 @@
  * have thread-unsafe res_search(). It's unset if we have the preferred
  * res_nsearch().
  */
-#define MONGOC_HAVE_RES_SEARCH 0
+#define MONGOC_HAVE_RES_SEARCH 1
 
 #if MONGOC_HAVE_RES_SEARCH != 1
 #  undef MONGOC_HAVE_RES_SEARCH
@@ -368,26 +372,6 @@
  */
 #define MONGOC_TRACE 0
 
-enum {
-   /**
-    * @brief Compile-time constant determining whether the mongoc library was
-    * compiled with tracing enabled.
-    *
-    * Can be controlled with the 'ENABLE_TRACING" configure-time boolean option
-    */
-   MONGOC_TRACE_ENABLED = MONGOC_TRACE
-};
-
-/*
- * Set if we have ICU support.
- */
-#define MONGOC_ENABLE_ICU 1
-
-#if MONGOC_ENABLE_ICU != 1
-#  undef MONGOC_ENABLE_ICU
-#endif
-
-
 /*
  * Set if we have Client Side Encryption support.
  */
@@ -418,6 +402,23 @@ enum {
 #  undef MONGOC_ENABLE_MONGODB_AWS_AUTH
 #endif
 
+enum {
+   /**
+    * @brief Compile-time constant determining whether the mongoc library was
+    * compiled with tracing enabled.
+    *
+    * Can be controlled with the “ENABLE_TRACING” configure-time boolean option
+    */
+   MONGOC_TRACE_ENABLED = MONGOC_TRACE,
+   /**
+    * @brief Compile-time constant indicating whether the mongoc library was
+    * compiled with SRV server discovery support.
+    *
+    * Can be controled with the “ENABLE_SRV” configure-time boolean option.
+    */
+   MONGOC_SRV_ENABLED = MONGOC_ENABLE_SRV,
+};
+
 /* clang-format on */
 
 #endif /* MONGOC_CONFIG_H */
